@@ -7,8 +7,8 @@ __docformat__ = 'restructuredtext en'
 
 import numbers
 from collections import defaultdict
+from collections.abc import Iterable
 from datetime import datetime, timedelta
-from typing import Iterable
 
 from calibre.ebooks.metadata import author_to_author_sort
 from calibre.utils.date import UNDEFINED_DATE, parse_date, utc_tz
@@ -20,6 +20,7 @@ from polyglot.builtins import iteritems, itervalues
 def identity(x):
     return x
 
+
 def c_parse(val):
     try:
         year, month, day, hour, minutes, seconds, tzsecs = _c_speedup(val)
@@ -30,7 +31,7 @@ def c_parse(val):
             return datetime(int(val), 1, 3, tzinfo=utc_tz)
         if val is None:
             return UNDEFINED_DATE
-    except:
+    except Exception:
         pass
     else:
         try:
@@ -71,7 +72,7 @@ class Table:
             self.unserialize = lambda x: x.replace('|', ',') if x else ''
             self.serialize = lambda x: x.replace(',', '|')
         self.link_table = (link_table if link_table else
-                'books_%s_link'%self.metadata['table'])
+                'books_{}_link'.format(self.metadata['table']))
         if self.supports_notes and dt == 'rating':  # custom ratings table
             self.supports_notes = False
 
@@ -90,7 +91,6 @@ class Table:
 
 
 class VirtualTable(Table):
-
     '''
     A dummy table used for fields that only exist in memory like ondevice
     '''
@@ -102,7 +102,6 @@ class VirtualTable(Table):
 
 
 class OneToOneTable(Table):
-
     '''
     Represents data that is unique per book (it may not actually be unique) but
     each item is assigned to a book in a one-to-one mapping. For example: uuid,
@@ -197,7 +196,6 @@ class CompositeTable(OneToOneTable):
 
 
 class ManyToOneTable(Table):
-
     '''
     Represents data where one data item can map to many books, for example:
     series or publisher.
@@ -234,7 +232,7 @@ class ManyToOneTable(Table):
             bcm[book] = item_id
 
     def fix_link_table(self, db):
-        linked_item_ids = {item_id for item_id in itervalues(self.book_col_map)}
+        linked_item_ids = set(itervalues(self.book_col_map))
         extra_item_ids = linked_item_ids - set(self.id_map)
         if extra_item_ids:
             for item_id in extra_item_ids:
@@ -409,7 +407,6 @@ class RatingTable(ManyToOneTable):
 
 
 class ManyToManyTable(ManyToOneTable):
-
     '''
     Represents data that has a many-to-many mapping with books. i.e. each book
     can have more than one value and each value can be mapped to more than one
@@ -518,7 +515,8 @@ class ManyToManyTable(ManyToOneTable):
         if existing_item is None or existing_item == item_id:
             # A simple rename will do the trick
             self.id_map[item_id] = new_name
-            db.execute(f'UPDATE {table} SET {col}=? WHERE id=?', (new_name, item_id))
+            nn = self.serialize(new_name) if self.serialize else new_name
+            db.execute(f'UPDATE {table} SET {col}=? WHERE id=?', (nn, item_id))
         else:
             # We have to replace
             new_id = existing_item
