@@ -5,12 +5,12 @@ __license__   = 'GPL v3'
 __copyright__ = '2012, Kovid Goyal <kovid at kovidgoyal.net>'
 __docformat__ = 'restructuredtext en'
 
-import traceback, re
+import re
+import traceback
 
 from calibre.constants import iswindows
 from polyglot.builtins import iteritems
 
-
 supernote_settings = {
     'calibre_file_paths': {'metadata':'Document/metadata.calibre', 'driveinfo':'Document/driveinfo.calibre'},
     'send_to': ['Document', 'Documents'],
@@ -26,6 +26,7 @@ class DeviceDefaults:
                     'format_map': ['azw3', 'mobi', 'azw',
                                     'azw1', 'azw4', 'kfx', 'pdf'],
                     'send_to': ['documents', 'kindle', 'books'],
+                    'apnx': {'send': True, 'method': 'fast', 'custom_column_page_count': None, 'custom_column_method': None}
                     }
                 ),
                 # B&N devices
@@ -36,9 +37,11 @@ class DeviceDefaults:
                     'send_to': ['NOOK/My Books', 'NOOK/My Files', 'NOOK', 'Calibre_Companion', 'Books', 'eBooks/import', 'eBooks', 'sdcard/ebooks'],
                     }
                 ),
-                # Supernote A5 and A5X
+                # Supernote A5 and A5X and A6X2
                 ({'vendor': 0x2207, 'product': 0x0031}, supernote_settings),
                 ({'vendor': 0x2207, 'product': 0x0011}, supernote_settings),
+                ({'vendor': 0x2207, 'product': 0x0007}, supernote_settings),  # A6X2
+                ({'vendor': 0x2207, 'product': 0x0017}, supernote_settings),  # A6X2
         )
 
     def __call__(self, device, driver):
@@ -48,7 +51,7 @@ class DeviceDefaults:
             if m is not None:
                 try:
                     vid, pid = int(m.group(1), 16), int(m.group(2), 16)
-                except:
+                except Exception:
                     traceback.print_exc()
         else:
             vid, pid = device.vendor_id, device.product_id
