@@ -93,15 +93,7 @@ class UpdateEditorGeometry:
             new_width += r.width()
 
         # Compute the maximum we can show if we consume the entire viewport
-        pin_view = self.table_widget.pin_view
-        is_pin_view, p = False, editor.parent()
-        while p is not None:
-            if p is pin_view:
-                is_pin_view = True
-                break
-            p = p.parent()
-
-        max_width = (pin_view if is_pin_view else self.table_widget).viewport().rect().width()
+        max_width = self.parent().viewport().rect().width()
         # What we have to display might not fit. If so, adjust down
         new_width = new_width if new_width < max_width else max_width
 
@@ -134,12 +126,14 @@ class UpdateEditorGeometry:
         initial_geometry.adjust(delta_x, 0, delta_width, 0)
         editor.setGeometry(initial_geometry)
 
+
 class EditableTextDelegate:
 
-    def setEditorData(self, editor, index):
+    def set_editor_data(self, editor, index):
         n = editor.metaObject().userProperty().name()
         editor.setProperty(n, get_val_for_textlike_columns(index))
 
+
 class DateTimeEdit(DateTimeEditBase):  # {{{
 
     def __init__(self, parent, format_):
@@ -151,8 +145,8 @@ class DateTimeEdit(DateTimeEditBase):  # {{{
 
 # }}}
 
-# Number Editor  {{{
 
+# Number Editor {{{
 
 def make_clearing_spinbox(spinbox):
 
@@ -184,8 +178,8 @@ ClearingDoubleSpinBox = make_clearing_spinbox(QDoubleSpinBox)
 
 # }}}
 
-# setter for text-like delegates. Return '' if CTRL is pushed {{{
 
+# setter for text-like delegates. Return '' if CTRL is pushed {{{
 
 def check_key_modifier(which_modifier):
     v = QApplication.keyboardModifiers() & (Qt.KeyboardModifier.ControlModifier | Qt.KeyboardModifier.ShiftModifier)
@@ -202,12 +196,42 @@ def get_val_for_textlike_columns(index_):
 # }}}
 
 
-class RatingDelegate(QStyledItemDelegate, UpdateEditorGeometry):  # {{{
+class StyledItemDelegate(QStyledItemDelegate):
+    '''
+    Set the flag ignore_kb_mods_on_edit before opening an editor if you don't
+    want keyboard modifiers taken into account, for example when using Shift-Tab
+    as a backtab when editing cells. This prevents opening dialogs by mistake.
+    See giu2.library.views.closeEditor() for an example.
+    '''
+    is_editable_with_tab = True  # sub-classes set to False is needed
+    ignore_kb_mods_on_edit = False
+
+    def createEditor(self, parent, option, index):
+        e = self.create_editor(parent, option, index)
+        return e
+
+    def setEditorData(self, editor, index):
+        # This method exists because of the ignore_kb_mods_on_edit flag. The
+        # flag is cleared after the editor data is set, in set_editor_data. It
+        # is possible that the subclass doesn't implement set_editor_data(). I
+        # can't find a case where this is true, but just in case call the
+        # default.
+        if hasattr(self, 'set_editor_data'):
+            self.set_editor_data(editor, index)
+        else:
+            super().setEditorData(editor, index)
+        self.ignore_kb_mods_on_edit = False
+
+    def create_editor(self, parent, option, index):
+        # Must be overridden by the "real" createEditor
+        raise NotImplementedError
+
+
+class RatingDelegate(StyledItemDelegate, UpdateEditorGeometry):  # {{{
 
     def __init__(self, *args, **kwargs):
-        QStyledItemDelegate.__init__(self, *args)
+        StyledItemDelegate.__init__(self, *args)
         self.is_half_star = kwargs.get('is_half_star', False)
-        self.table_widget = args[0]
         self.rf = QFont(rating_font())
         self.em = Qt.TextElideMode.ElideMiddle
         delta = 0
@@ -221,10 +245,10 @@ class RatingDelegate(QStyledItemDelegate, UpdateEditorGeometry):  # {{{
     def displayText(self, value, locale):
         return rating_to_stars(value, self.is_half_star)
 
-    def createEditor(self, parent, option, index):
+    def create_editor(self, parent, option, index):
         return RatingEditor(parent, is_half_star=self.is_half_star)
 
-    def setEditorData(self, editor, index):
+    def set_editor_data(self, editor, index):
         if check_key_modifier(Qt.KeyboardModifier.ControlModifier):
             val = 0
         else:
@@ -238,22 +262,21 @@ class RatingDelegate(QStyledItemDelegate, UpdateEditorGeometry):  # {{{
     def sizeHint(self, option, index):
         option.font = self.rf
         option.textElideMode = self.em
-        return QStyledItemDelegate.sizeHint(self, option, index)
+        return StyledItemDelegate.sizeHint(self, option, index)
 
     def paint(self, painter, option, index):
         option.font = self.rf
         option.textElideMode = self.em
-        return QStyledItemDelegate.paint(self, painter, option, index)
+        return StyledItemDelegate.paint(self, painter, option, index)
 
 # }}}
 
 
-class DateDelegate(QStyledItemDelegate, UpdateEditorGeometry):  # {{{
+class DateDelegate(StyledItemDelegate, UpdateEditorGeometry):  # {{{
 
     def __init__(self, parent, tweak_name='gui_timestamp_display_format',
             default_format='dd MMM yyyy'):
-        QStyledItemDelegate.__init__(self, parent)
-        self.table_widget = parent
+        StyledItemDelegate.__init__(self, parent)
         self.tweak_name = tweak_name
         self.format = tweaks[self.tweak_name]
         if self.format is None:
@@ -265,13 +288,13 @@ class DateDelegate(QStyledItemDelegate, UpdateEditorGeometry):  # {{{
             return ''
         return format_date(d, self.format)
 
-    def createEditor(self, parent, option, index):
+    def create_editor(self, parent, option, index):
         return DateTimeEdit(parent, self.format)
 
-    def setEditorData(self, editor, index):
+    def set_editor_data(self, editor, index):
         if check_key_modifier(Qt.KeyboardModifier.ControlModifier):
             val = UNDEFINED_QDATETIME
-        elif check_key_modifier(Qt.KeyboardModifier.ShiftModifier | Qt.KeyboardModifier.ControlModifier):
+        elif not self.ignore_kb_mods_on_edit and check_key_modifier(Qt.KeyboardModifier.ShiftModifier):
             val = now()
         else:
             val = index.data(Qt.ItemDataRole.EditRole)
@@ -284,12 +307,11 @@ class DateDelegate(QStyledItemDelegate, UpdateEditorGeometry):  # {{{
 # }}}
 
 
-class PubDateDelegate(QStyledItemDelegate, UpdateEditorGeometry):  # {{{
+class PubDateDelegate(StyledItemDelegate, UpdateEditorGeometry):  # {{{
 
     def __init__(self, *args, **kwargs):
-        QStyledItemDelegate.__init__(self, *args, **kwargs)
+        StyledItemDelegate.__init__(self, *args, **kwargs)
         self.format = tweaks['gui_pubdate_display_format']
-        self.table_widget = args[0]
         if self.format is None:
             self.format = 'MMM yyyy'
 
@@ -299,14 +321,14 @@ class PubDateDelegate(QStyledItemDelegate, UpdateEditorGeometry):  # {{{
             return ''
         return format_date(d, self.format)
 
-    def createEditor(self, parent, option, index):
+    def create_editor(self, parent, option, index):
         return DateTimeEdit(parent, self.format)
 
-    def setEditorData(self, editor, index):
+    def set_editor_data(self, editor, index):
         val = index.data(Qt.ItemDataRole.EditRole)
         if check_key_modifier(Qt.KeyboardModifier.ControlModifier):
             val = UNDEFINED_QDATETIME
-        elif check_key_modifier(Qt.KeyboardModifier.ShiftModifier | Qt.KeyboardModifier.ControlModifier):
+        elif not self.ignore_kb_mods_on_edit and check_key_modifier(Qt.KeyboardModifier.ShiftModifier):
             val = now()
         elif is_date_undefined(val):
             val = QDate.currentDate()
@@ -317,32 +339,25 @@ class PubDateDelegate(QStyledItemDelegate, UpdateEditorGeometry):  # {{{
 # }}}
 
 
-class TextDelegate(QStyledItemDelegate, UpdateEditorGeometry, EditableTextDelegate):  # {{{
+class TextDelegate(StyledItemDelegate, UpdateEditorGeometry, EditableTextDelegate):  # {{{
 
     use_title_sort = False
+    auto_complete_function_name = ''
 
-    def __init__(self, parent):
-        '''
-        Delegate for text data. If auto_complete_function needs to return a list
-        of text items to auto-complete with. If the function is None no
-        auto-complete will be used.
-        '''
-        QStyledItemDelegate.__init__(self, parent)
-        self.table_widget = parent
-        self.auto_complete_function = None
-
-    def set_auto_complete_function(self, f):
-        self.auto_complete_function = f
-
-    def createEditor(self, parent, option, index):
-        if self.auto_complete_function:
+    def create_editor(self, parent, option, index):
+        db = index.model().db
+        if self.auto_complete_function_name and (f := getattr(db, self.auto_complete_function_name, None)):
             if self.use_title_sort:
                 editor = EditWithComplete(parent, sort_func=title_sort)
             else:
                 editor = EditWithComplete(parent)
             editor.set_separator(None)
             editor.set_clear_button_enabled(False)
-            complete_items = [i[1] for i in self.auto_complete_function()]
+            if self.auto_complete_function_name.startswith('all_'):
+                field = self.auto_complete_function_name[4:]
+                if field in db.new_api.pref('categories_using_hierarchy', default=()):
+                    editor.set_hierarchy_separator('.')
+            complete_items = [i[1] for i in f()]
             editor.update_items_cache(complete_items)
         else:
             editor = EnLineEdit(parent)
@@ -353,7 +368,7 @@ class TextDelegate(QStyledItemDelegate, UpdateEditorGeometry, EditableTextDelega
             val = editor.lineEdit().text()
             model.setData(index, (val), Qt.ItemDataRole.EditRole)
         else:
-            QStyledItemDelegate.setModelData(self, editor, model, index)
+            StyledItemDelegate.setModelData(self, editor, model, index)
 
 # }}}
 
@@ -361,6 +376,7 @@ class TextDelegate(QStyledItemDelegate, UpdateEditorGeometry, EditableTextDelega
 class SeriesDelegate(TextDelegate):  # {{{
 
     use_title_sort = True
+    auto_complete_function_name = 'all_series'
 
     def initStyleOption(self, option, index):
         TextDelegate.initStyleOption(self, option, index)
@@ -368,42 +384,41 @@ class SeriesDelegate(TextDelegate):  # {{{
 # }}}
 
 
-class CompleteDelegate(QStyledItemDelegate, UpdateEditorGeometry, EditableTextDelegate):  # {{{
+class CompleteDelegate(StyledItemDelegate, UpdateEditorGeometry, EditableTextDelegate):  # {{{
 
     def __init__(self, parent, sep, items_func_name, space_before_sep=False):
-        QStyledItemDelegate.__init__(self, parent)
+        StyledItemDelegate.__init__(self, parent)
         self.sep = sep
         self.items_func_name = items_func_name
         self.space_before_sep = space_before_sep
-        self.table_widget = parent
 
-    def set_database(self, db):
-        self.db = db
-
-    def createEditor(self, parent, option, index):
-        if self.db and hasattr(self.db, self.items_func_name):
+    def create_editor(self, parent, option, index):
+        db = index.model().db
+        if hasattr(db, self.items_func_name):
             m = index.model()
             col = m.column_map[index.column()]
             # If shifted, bring up the tag editor instead of the line editor.
-            if check_key_modifier(Qt.KeyboardModifier.ShiftModifier) and col != 'authors':
+            if not self.ignore_kb_mods_on_edit and check_key_modifier(Qt.KeyboardModifier.ShiftModifier) and col != 'authors':
                 key = col if m.is_custom_column(col) else None
-                d = TagEditor(parent, self.db, m.id(index.row()), key=key)
+                d = TagEditor(parent, db, m.id(index.row()), key=key)
                 if d.exec() == QDialog.DialogCode.Accepted:
                     m.setData(index, self.sep.join(d.tags), Qt.ItemDataRole.EditRole)
                 return None
             editor = EditWithComplete(parent)
             if col == 'tags':
                 editor.set_elide_mode(Qt.TextElideMode.ElideMiddle)
+            if col in db.new_api.pref('categories_using_hierarchy', default=()):
+                editor.set_hierarchy_separator('.')
             editor.set_separator(self.sep)
             editor.set_clear_button_enabled(False)
             editor.set_space_before_sep(self.space_before_sep)
             if self.sep == '&':
                 editor.set_add_separator(tweaks['authors_completer_append_separator'])
             if not m.is_custom_column(col):
-                all_items = getattr(self.db, self.items_func_name)()
+                all_items = getattr(db, self.items_func_name)()
             else:
-                all_items = list(self.db.all_custom(
-                    label=self.db.field_metadata.key_to_label(col)))
+                all_items = list(db.all_custom(
+                    label=db.field_metadata.key_to_label(col)))
             editor.update_items_cache(all_items)
         else:
             editor = EnLineEdit(parent)
@@ -414,22 +429,21 @@ class CompleteDelegate(QStyledItemDelegate, UpdateEditorGeometry, EditableTextDe
             val = editor.lineEdit().text()
             model.setData(index, (val), Qt.ItemDataRole.EditRole)
         else:
-            QStyledItemDelegate.setModelData(self, editor, model, index)
+            StyledItemDelegate.setModelData(self, editor, model, index)
 # }}}
 
 
-class LanguagesDelegate(QStyledItemDelegate, UpdateEditorGeometry):  # {{{
+class LanguagesDelegate(StyledItemDelegate, UpdateEditorGeometry):  # {{{
 
     def __init__(self, parent):
-        QStyledItemDelegate.__init__(self, parent)
-        self.table_widget = parent
+        StyledItemDelegate.__init__(self, parent)
 
-    def createEditor(self, parent, option, index):
+    def create_editor(self, parent, option, index):
         editor = LanguagesEdit(parent=parent)
         editor.init_langs(index.model().db)
         return editor
 
-    def setEditorData(self, editor, index):
+    def set_editor_data(self, editor, index):
         editor.show_initial_value(get_val_for_textlike_columns(index))
 
     def setModelData(self, editor, model, index):
@@ -439,7 +453,7 @@ class LanguagesDelegate(QStyledItemDelegate, UpdateEditorGeometry):  # {{{
 # }}}
 
 
-class CcDateDelegate(QStyledItemDelegate, UpdateEditorGeometry):  # {{{
+class CcDateDelegate(StyledItemDelegate, UpdateEditorGeometry):  # {{{
 
     '''
     Delegate for custom columns dates. Because this delegate stores the
@@ -448,8 +462,7 @@ class CcDateDelegate(QStyledItemDelegate, UpdateEditorGeometry):  # {{{
     '''
 
     def __init__(self, parent):
-        QStyledItemDelegate.__init__(self, parent)
-        self.table_widget = parent
+        StyledItemDelegate.__init__(self, parent)
 
     def set_format(self, _format):
         if not _format:
@@ -465,13 +478,13 @@ class CcDateDelegate(QStyledItemDelegate, UpdateEditorGeometry):  # {{{
             return ''
         return format_date(d, self.format)
 
-    def createEditor(self, parent, option, index):
+    def create_editor(self, parent, option, index):
         return DateTimeEdit(parent, self.format)
 
-    def setEditorData(self, editor, index):
+    def set_editor_data(self, editor, index):
         if check_key_modifier(Qt.KeyboardModifier.ControlModifier):
             val = UNDEFINED_QDATETIME
-        elif check_key_modifier(Qt.KeyboardModifier.ShiftModifier | Qt.KeyboardModifier.ControlModifier):
+        elif not self.ignore_kb_mods_on_edit and check_key_modifier(Qt.KeyboardModifier.ShiftModifier):
             val = now()
         else:
             val = index.data(Qt.ItemDataRole.EditRole)
@@ -490,7 +503,7 @@ class CcDateDelegate(QStyledItemDelegate, UpdateEditorGeometry):  # {{{
 # }}}
 
 
-class CcTextDelegate(QStyledItemDelegate, UpdateEditorGeometry, EditableTextDelegate):  # {{{
+class CcTextDelegate(StyledItemDelegate, UpdateEditorGeometry, EditableTextDelegate):  # {{{
 
     '''
     Delegate for text data.
@@ -498,10 +511,9 @@ class CcTextDelegate(QStyledItemDelegate, UpdateEditorGeometry, EditableTextDele
     use_title_sort = False
 
     def __init__(self, parent):
-        QStyledItemDelegate.__init__(self, parent)
-        self.table_widget = parent
+        StyledItemDelegate.__init__(self, parent)
 
-    def createEditor(self, parent, option, index):
+    def create_editor(self, parent, option, index):
         m = index.model()
         col = m.column_map[index.column()]
         key = m.db.field_metadata.key_to_label(col)
@@ -512,7 +524,9 @@ class CcTextDelegate(QStyledItemDelegate, UpdateEditorGeometry, EditableTextDele
                 editor = EditWithComplete(parent)
             editor.set_separator(None)
             editor.set_clear_button_enabled(False)
-            complete_items = sorted(list(m.db.all_custom(label=key)), key=sort_key)
+            if col in m.db.new_api.pref('categories_using_hierarchy', default=()):
+                editor.set_hierarchy_separator('.')
+            complete_items = sorted(m.db.all_custom(label=key), key=sort_key)
             editor.update_items_cache(complete_items)
         else:
             editor = QLineEdit(parent)
@@ -539,17 +553,18 @@ class CcSeriesDelegate(CcTextDelegate):  # {{{
 # }}}
 
 
-class CcLongTextDelegate(QStyledItemDelegate):  # {{{
+class CcLongTextDelegate(StyledItemDelegate):  # {{{
 
     '''
     Delegate for comments data.
     '''
 
     def __init__(self, parent):
-        QStyledItemDelegate.__init__(self, parent)
+        StyledItemDelegate.__init__(self, parent)
         self.document = QTextDocument()
+        self.is_editable_with_tab = False
 
-    def createEditor(self, parent, option, index):
+    def create_editor(self, parent, option, index):
         m = index.model()
         col = m.column_map[index.column()]
         if check_key_modifier(Qt.KeyboardModifier.ControlModifier):
@@ -559,14 +574,13 @@ class CcLongTextDelegate(QStyledItemDelegate):  # {{{
         d = PlainTextDialog(parent, text, column_name=m.custom_columns[col]['name'])
         if d.exec() == QDialog.DialogCode.Accepted:
             m.setData(index, d.text, Qt.ItemDataRole.EditRole)
-        return None
 
     def setModelData(self, editor, model, index):
         model.setData(index, (editor.textbox.html), Qt.ItemDataRole.EditRole)
 # }}}
 
 
-class CcMarkdownDelegate(QStyledItemDelegate):  # {{{
+class CcMarkdownDelegate(StyledItemDelegate):  # {{{
 
     '''
     Delegate for markdown data.
@@ -575,6 +589,7 @@ class CcMarkdownDelegate(QStyledItemDelegate):  # {{{
     def __init__(self, parent):
         super().__init__(parent)
         self.document = QTextDocument()
+        self.is_editable_with_tab = False
 
     def paint(self, painter, option, index):
         self.initStyleOption(option, index)
@@ -598,7 +613,7 @@ class CcMarkdownDelegate(QStyledItemDelegate):  # {{{
         self.document.documentLayout().draw(painter, ctx)
         painter.restore()
 
-    def createEditor(self, parent, option, index):
+    def create_editor(self, parent, option, index):
         m = index.model()
         col = m.column_map[index.column()]
         if check_key_modifier(Qt.KeyboardModifier.ControlModifier):
@@ -612,24 +627,22 @@ class CcMarkdownDelegate(QStyledItemDelegate):  # {{{
                                base_url=base_url)
         if d.exec() == QDialog.DialogCode.Accepted:
             m.setData(index, (d.text), Qt.ItemDataRole.EditRole)
-        return None
 
     def setModelData(self, editor, model, index):
         model.setData(index, (editor.textbox.html), Qt.ItemDataRole.EditRole)
 # }}}
 
 
-class CcNumberDelegate(QStyledItemDelegate, UpdateEditorGeometry):  # {{{
+class CcNumberDelegate(StyledItemDelegate, UpdateEditorGeometry):  # {{{
 
     '''
     Delegate for text/int/float data.
     '''
 
     def __init__(self, parent):
-        QStyledItemDelegate.__init__(self, parent)
-        self.table_widget = parent
+        StyledItemDelegate.__init__(self, parent)
 
-    def createEditor(self, parent, option, index):
+    def create_editor(self, parent, option, index):
         m = index.model()
         col = m.column_map[index.column()]
         if m.custom_columns[col]['datatype'] == 'int':
@@ -651,7 +664,7 @@ class CcNumberDelegate(QStyledItemDelegate, UpdateEditorGeometry):  # {{{
         model.setData(index, (val), Qt.ItemDataRole.EditRole)
         editor.adjustSize()
 
-    def setEditorData(self, editor, index):
+    def set_editor_data(self, editor, index):
         m = index.model()
         val = m.db.data[index.row()][m.custom_columns[m.column_map[index.column()]]['rec_index']]
         if check_key_modifier(Qt.KeyboardModifier.ControlModifier):
@@ -670,18 +683,17 @@ class CcNumberDelegate(QStyledItemDelegate, UpdateEditorGeometry):  # {{{
 # }}}
 
 
-class CcEnumDelegate(QStyledItemDelegate, UpdateEditorGeometry):  # {{{
+class CcEnumDelegate(StyledItemDelegate, UpdateEditorGeometry):  # {{{
 
     '''
     Delegate for text/int/float data.
     '''
 
     def __init__(self, parent):
-        QStyledItemDelegate.__init__(self, parent)
-        self.table_widget = parent
+        StyledItemDelegate.__init__(self, parent)
         self.longest_text = ''
 
-    def createEditor(self, parent, option, index):
+    def create_editor(self, parent, option, index):
         m = index.model()
         col = m.column_map[index.column()]
         editor = DelegateCB(parent)
@@ -705,7 +717,7 @@ class CcEnumDelegate(QStyledItemDelegate, UpdateEditorGeometry):  # {{{
                                    self.longest_text + 'M')
         return srect.width()
 
-    def setEditorData(self, editor, index):
+    def set_editor_data(self, editor, index):
         m = index.model()
         val = m.db.data[index.row()][m.custom_columns[m.column_map[index.column()]]['rec_index']]
         if val is None or check_key_modifier(Qt.KeyboardModifier.ControlModifier):
@@ -718,15 +730,16 @@ class CcEnumDelegate(QStyledItemDelegate, UpdateEditorGeometry):  # {{{
 # }}}
 
 
-class CcCommentsDelegate(QStyledItemDelegate):  # {{{
+class CcCommentsDelegate(StyledItemDelegate):  # {{{
 
     '''
     Delegate for comments data.
     '''
 
     def __init__(self, parent):
-        QStyledItemDelegate.__init__(self, parent)
+        StyledItemDelegate.__init__(self, parent)
         self.document = QTextDocument()
+        self.is_editable_with_tab = False
 
     def paint(self, painter, option, index):
         self.initStyleOption(option, index)
@@ -750,7 +763,7 @@ class CcCommentsDelegate(QStyledItemDelegate):  # {{{
         self.document.documentLayout().draw(painter, ctx)
         painter.restore()
 
-    def createEditor(self, parent, option, index):
+    def create_editor(self, parent, option, index):
         m = index.model()
         col = m.column_map[index.column()]
         if check_key_modifier(Qt.KeyboardModifier.ControlModifier):
@@ -761,7 +774,6 @@ class CcCommentsDelegate(QStyledItemDelegate):  # {{{
         d = editor.exec()
         if d:
             m.setData(index, (editor.textbox.html), Qt.ItemDataRole.EditRole)
-        return None
 
     def setModelData(self, editor, model, index):
         model.setData(index, (editor.textbox.html), Qt.ItemDataRole.EditRole)
@@ -780,17 +792,16 @@ class DelegateCB(QComboBox):  # {{{
 # }}}
 
 
-class CcBoolDelegate(QStyledItemDelegate, UpdateEditorGeometry):  # {{{
+class CcBoolDelegate(StyledItemDelegate, UpdateEditorGeometry):  # {{{
 
     def __init__(self, parent):
         '''
         Delegate for custom_column bool data.
         '''
         self.nuke_option_data = False
-        QStyledItemDelegate.__init__(self, parent)
-        self.table_widget = parent
+        StyledItemDelegate.__init__(self, parent)
 
-    def createEditor(self, parent, option, index):
+    def create_editor(self, parent, option, index):
         editor = DelegateCB(parent)
         items = [_('Yes'), _('No'), _('Undefined')]
         icons = ['ok.png', 'list_remove.png', 'blank.png']
@@ -813,7 +824,7 @@ class CcBoolDelegate(QStyledItemDelegate, UpdateEditorGeometry):  # {{{
         val = {0:True, 1:False, 2:None}[editor.currentIndex()]
         model.setData(index, val, Qt.ItemDataRole.EditRole)
 
-    def setEditorData(self, editor, index):
+    def set_editor_data(self, editor, index):
         m = index.model()
         val = m.db.data[index.row()][m.custom_columns[m.column_map[index.column()]]['rec_index']]
         if not m.db.new_api.pref('bools_are_tristate'):
@@ -844,16 +855,17 @@ class CcBoolDelegate(QStyledItemDelegate, UpdateEditorGeometry):  # {{{
 # }}}
 
 
-class CcTemplateDelegate(QStyledItemDelegate):  # {{{
+class CcTemplateDelegate(StyledItemDelegate):  # {{{
 
     def __init__(self, parent):
         '''
         Delegate for composite custom_columns.
         '''
-        QStyledItemDelegate.__init__(self, parent)
+        StyledItemDelegate.__init__(self, parent)
         self.disallow_edit = gprefs['edit_metadata_templates_only_F2_on_booklist']
+        self.is_editable_with_tab = False
 
-    def createEditor(self, parent, option, index):
+    def create_editor(self, parent, option, index):
         if self.disallow_edit:
             editor = QLineEdit(parent)
             editor.setText(_('Template editing disabled'))
@@ -867,7 +879,7 @@ class CcTemplateDelegate(QStyledItemDelegate):  # {{{
         else:
             text = m.custom_columns[m.column_map[index.column()]]['display']['composite_template']
         editor = TemplateDialog(parent, text, mi)
-        editor.setWindowTitle(_("Edit template"))
+        editor.setWindowTitle(_('Edit template'))
         editor.textbox.setTabChangesFocus(False)
         editor.textbox.setTabStopDistance(20)
         d = editor.exec()
@@ -875,7 +887,7 @@ class CcTemplateDelegate(QStyledItemDelegate):  # {{{
             m.setData(index, (editor.rule[1]), Qt.ItemDataRole.EditRole)
         return None
 
-    def setEditorData(self, editor, index):
+    def set_editor_data(self, editor, index):
         editor.setText('editing templates disabled')
         editor.setReadOnly(True)
 
