@@ -1,5 +1,4 @@
 #!/usr/bin/env python
-# vim:fileencoding=UTF-8:ts=4:sw=4:sta:et:sts=4:fdm=marker:ai
 # License: GPLv3 Copyright: 2013, Kovid Goyal <kovid at kovidgoyal.net>
 
 
@@ -8,30 +7,52 @@ import sys
 import tempfile
 import textwrap
 from functools import partial
-from qt.core import (
-    QAbstractItemView, QApplication, QCheckBox, QCursor, QDialog, QDialogButtonBox,
-    QEvent, QFrame, QGridLayout, QIcon, QInputDialog, QItemSelectionModel,
-    QKeySequence, QLabel, QMenu, QPushButton, QScrollArea, QSize, QSizePolicy,
-    QStackedWidget, Qt, QToolButton, QTreeWidget, QTreeWidgetItem, QVBoxLayout,
-    QWidget, pyqtSignal
-)
 from threading import Thread
 from time import monotonic
 
-from calibre.constants import TOC_DIALOG_APP_UID, islinux, iswindows
+from qt.core import (
+    QAbstractItemView,
+    QCheckBox,
+    QCursor,
+    QDialog,
+    QDialogButtonBox,
+    QEvent,
+    QFrame,
+    QGridLayout,
+    QIcon,
+    QInputDialog,
+    QItemSelectionModel,
+    QKeySequence,
+    QLabel,
+    QMenu,
+    QPushButton,
+    QScrollArea,
+    QSize,
+    QSizePolicy,
+    QStackedWidget,
+    Qt,
+    QTimer,
+    QToolButton,
+    QTreeWidget,
+    QTreeWidgetItem,
+    QVBoxLayout,
+    QWidget,
+    pyqtSignal,
+)
+
+from calibre.constants import TOC_DIALOG_APP_UID, islinux, ismacos, iswindows
 from calibre.ebooks.oeb.polish.container import AZW3Container, get_container
-from calibre.ebooks.oeb.polish.toc import (
-    TOC, add_id, commit_toc, from_files, from_links, from_xpaths, get_toc
-)
-from calibre.gui2 import (
-    Application, error_dialog, info_dialog, question_dialog, set_app_uid
-)
+from calibre.ebooks.oeb.polish.toc import TOC, add_id, commit_toc, from_files, from_links, from_xpaths, get_toc
+from calibre.gui2 import Application, error_dialog, info_dialog, set_app_uid
 from calibre.gui2.convert.xpath_wizard import XPathEdit
 from calibre.gui2.progress_indicator import ProgressIndicator
 from calibre.gui2.toc.location import ItemEdit
 from calibre.ptempfile import reset_base_dir
+from calibre.startup import connect_lambda
 from calibre.utils.config import JSONConfig
 from calibre.utils.filenames import atomic_rename
+from calibre.utils.icu import lower as icu_lower
+from calibre.utils.icu import upper as icu_upper
 from calibre.utils.logging import GUILog
 
 ICON_SIZE = 24
@@ -53,7 +74,7 @@ class XPathDialog(QDialog):  # {{{
         l.addWidget(la)
         self.widgets = []
         for i in range(5):
-            la = _('Level %s ToC:')%('&%d'%(i+1))
+            la = _('Level %s ToC:')%(f'&{i + 1}')
             xp = XPathEdit(self)
             xp.set_msg(la)
             self.widgets.append(xp)
@@ -141,7 +162,7 @@ class ItemView(QStackedWidget):  # {{{
     delete_item = pyqtSignal()
     flatten_item = pyqtSignal()
     go_to_root = pyqtSignal()
-    create_from_xpath = pyqtSignal(object, object)
+    create_from_xpath = pyqtSignal(object, object, object)
     create_from_links = pyqtSignal()
     create_from_files = pyqtSignal()
     flatten_toc = pyqtSignal()
@@ -249,7 +270,7 @@ class ItemView(QStackedWidget):  # {{{
         l.addWidget(la, 1, 0, 1, 2)
 
         # Item status
-        ip.hl1 = hl =  QFrame()
+        ip.hl1 = hl = QFrame()
         hl.setFrameShape(QFrame.Shape.HLine)
         l.addWidget(hl, l.rowCount(), 0, 1, 2)
         self.icon_label = QLabel()
@@ -257,51 +278,51 @@ class ItemView(QStackedWidget):  # {{{
         self.status_label.setWordWrap(True)
         l.addWidget(self.icon_label, l.rowCount(), 0)
         l.addWidget(self.status_label, l.rowCount()-1, 1)
-        ip.hl2 = hl =  QFrame()
+        ip.hl2 = hl = QFrame()
         hl.setFrameShape(QFrame.Shape.HLine)
         l.addWidget(hl, l.rowCount(), 0, 1, 2)
 
         # Edit/remove item
         rs = l.rowCount()
-        ip.b1 = b = QPushButton(QIcon(I('edit_input.png')),
+        ip.b1 = b = QPushButton(QIcon.ic('edit_input.png'),
             _('Change the &location this entry points to'), self)
         b.clicked.connect(self.edit_item)
         l.addWidget(b, l.rowCount()+1, 0, 1, 2)
-        ip.b2 = b = QPushButton(QIcon(I('trash.png')),
+        ip.b2 = b = QPushButton(QIcon.ic('trash.png'),
             _('&Remove this entry'), self)
         l.addWidget(b, l.rowCount(), 0, 1, 2)
         b.clicked.connect(self.delete_item)
-        ip.hl3 = hl =  QFrame()
+        ip.hl3 = hl = QFrame()
         hl.setFrameShape(QFrame.Shape.HLine)
         l.addWidget(hl, l.rowCount(), 0, 1, 2)
         l.setRowMinimumHeight(rs, 20)
 
         # Add new item
         rs = l.rowCount()
-        ip.b3 = b = QPushButton(QIcon(I('plus.png')), _('New entry &inside this entry'))
+        ip.b3 = b = QPushButton(QIcon.ic('plus.png'), _('New entry &inside this entry'))
         connect_lambda(b.clicked, self, lambda self: self.add_new('inside'))
         l.addWidget(b, l.rowCount()+1, 0, 1, 2)
-        ip.b4 = b = QPushButton(QIcon(I('plus.png')), _('New entry &above this entry'))
+        ip.b4 = b = QPushButton(QIcon.ic('plus.png'), _('New entry &above this entry'))
         connect_lambda(b.clicked, self, lambda self: self.add_new('before'))
         l.addWidget(b, l.rowCount(), 0, 1, 2)
-        ip.b5 = b = QPushButton(QIcon(I('plus.png')), _('New entry &below this entry'))
+        ip.b5 = b = QPushButton(QIcon.ic('plus.png'), _('New entry &below this entry'))
         connect_lambda(b.clicked, self, lambda self: self.add_new('after'))
         l.addWidget(b, l.rowCount(), 0, 1, 2)
         # Flatten entry
-        ip.b3 = b = QPushButton(QIcon(I('heuristics.png')), _('&Flatten this entry'))
+        ip.b3 = b = QPushButton(QIcon.ic('heuristics.png'), _('&Flatten this entry'))
         b.clicked.connect(self.flatten_item)
         b.setToolTip(_('All children of this entry are brought to the same '
                        'level as this entry.'))
         l.addWidget(b, l.rowCount()+1, 0, 1, 2)
 
-        ip.hl4 = hl =  QFrame()
+        ip.hl4 = hl = QFrame()
         hl.setFrameShape(QFrame.Shape.HLine)
         l.addWidget(hl, l.rowCount(), 0, 1, 2)
         l.setRowMinimumHeight(rs, 20)
 
         # Return to welcome
         rs = l.rowCount()
-        ip.b4 = b = QPushButton(QIcon(I('back.png')), _('&Return to welcome screen'))
+        ip.b4 = b = QPushButton(QIcon.ic('back.png'), _('&Return to welcome screen'))
         b.clicked.connect(self.go_to_root)
         b.setToolTip(_('Go back to the top level view'))
         l.addWidget(b, l.rowCount()+1, 0, 1, 2)
@@ -315,23 +336,42 @@ class ItemView(QStackedWidget):  # {{{
         self.w2.setWordWrap(True)
         l.addWidget(la, l.rowCount(), 0, 1, 2)
 
-    def ask_if_duplicates_should_be_removed(self):
-        return not question_dialog(self, _('Remove duplicates'), _(
-            'Should headings with the same text at the same level be included?'),
-            yes_text=_('&Include duplicates'), no_text=_('&Remove duplicates'))
+    def headings_question(self, xpaths):
+        from calibre.gui2.widgets2 import Dialog
+
+        class D(Dialog):
+            def __init__(self, parent):
+                super().__init__(_('Configure ToC generation'), 'configure-toc-from-headings', parent=parent)
+
+            def setup_ui(s):
+                s.l = l = QVBoxLayout(s)
+                s.remove_duplicates_cb = rd = QCheckBox(_('Remove &duplicated headings at the same ToC level'))
+                l.addWidget(rd)
+                rd.setChecked(bool(self.prefs.get('toc_from_headings_remove_duplicates', True)))
+                s.prefer_title_cb = pt = QCheckBox(_('Use the &title attribute for ToC text'))
+                l.addWidget(pt)
+                pt.setToolTip(textwrap.fill(_(
+                    'When a heading tag has the "title" attribute use its contents as the text for the ToC entry,'
+                    ' instead of the text inside the heading tag itself.')))
+                pt.setChecked(bool(self.prefs.get('toc_from_headings_prefer_title')))
+                l.addWidget(s.bb)
+
+        d = D(self)
+        if d.exec() == QDialog.DialogCode.Accepted:
+            self.create_from_xpath.emit(xpaths, d.remove_duplicates_cb.isChecked(), d.prefer_title_cb.isChecked())
+        self.prefs.set('toc_from_headings_remove_duplicates', d.remove_duplicates_cb.isChecked())
+        self.prefs.set('toc_from_headings_prefer_title', d.prefer_title_cb.isChecked())
 
     def create_from_major_headings(self):
-        self.create_from_xpath.emit(['//h:h%d'%i for i in range(1, 4)],
-                self.ask_if_duplicates_should_be_removed())
+        self.headings_question([f'//h:h{i}' for i in range(1, 4)])
 
     def create_from_all_headings(self):
-        self.create_from_xpath.emit(['//h:h%d'%i for i in range(1, 7)],
-                self.ask_if_duplicates_should_be_removed())
+        self.headings_question([f'//h:h{i}' for i in range(1, 7)])
 
     def create_from_user_xpath(self):
         d = XPathDialog(self, self.prefs)
-        if d.exec_() == QDialog.DialogCode.Accepted and d.xpaths:
-            self.create_from_xpath.emit(d.xpaths, d.remove_duplicates_cb.isChecked())
+        if d.exec() == QDialog.DialogCode.Accepted and d.xpaths:
+            self.create_from_xpath.emit(d.xpaths, d.remove_duplicates_cb.isChecked(), False)
 
     def hide_azw3_warning(self):
         self.w1.setVisible(False), self.w2.setVisible(False)
@@ -357,7 +397,7 @@ class ItemView(QStackedWidget):  # {{{
     def populate_item_pane(self):
         item = self.current_item
         name = str(item.data(0, Qt.ItemDataRole.DisplayRole) or '')
-        self.item_pane.heading.setText('<h2>%s</h2>'%name)
+        self.item_pane.heading.setText(f'<h2>{name}</h2>')
         self.icon_label.setPixmap(item.data(0, Qt.ItemDataRole.DecorationRole
                                             ).pixmap(32, 32))
         tt = _('This entry points to an existing destination')
@@ -481,113 +521,238 @@ class TreeWidget(QTreeWidget):  # {{{
     def selectedIndexes(self):
         ans = super().selectedIndexes()
         if self.in_drop_event:
-            # For order to be be preserved when moving by drag and drop, we
+            # For order to be preserved when moving by drag and drop, we
             # have to ensure that selectedIndexes returns an ordered list of
             # indexes.
             sort_map = {self.indexFromItem(item):i for i, item in enumerate(self.iter_items())}
-            ans = sorted(ans, key=lambda x:sort_map.get(x, -1))
+            ans = sorted(ans, key=lambda x: sort_map.get(x, -1))
         return ans
 
     def highlight_item(self, item):
         self.setCurrentItem(item, 0, QItemSelectionModel.SelectionFlag.ClearAndSelect)
         self.scrollToItem(item)
 
-    def check_multi_selection(self):
-        if len(self.selectedItems()) > 1:
-            info_dialog(self, _('Multiple items selected'), _(
-                'You are trying to move multiple items at once, this is not supported. Instead use'
-                ' Drag and Drop to move multiple items'), show=True)
-            return False
-        return True
+    def _sort_items_by_index(self, items, reverse=False):
+        def get_index(item):
+            result = []
+
+            parent = item.parent()
+            while parent is not None:
+                result.append(parent.indexOfChild(item))
+                item, parent = parent, parent.parent()
+
+            result.reverse()
+            return result
+
+        items.sort(key=get_index, reverse=reverse)
+
+    def _get_root_items(self, items):
+        items_ = []
+        for item in items:
+            if item is None:
+                continue
+
+            parent = item
+            while (parent := parent.parent()) is not None:
+                if parent in items:
+                    break
+            else:
+                items_.append(item)
+
+        return items_
+
+    def _move_indent_left(self, items):
+        self._sort_items_by_index(items)
+
+        for item in items:
+            old_parent = item.parent()
+            if old_parent is None:
+                return
+
+            old_index = old_parent.indexOfChild(item)
+            was_expanded = item.isExpanded() or item.childCount() == 0
+
+            new_parent = old_parent.parent() or self.invisibleRootItem()
+            new_index = new_parent.indexOfChild(old_parent) + 1
+
+            # all former lower siblings become children of indented item
+            for _ in range(old_parent.childCount() - old_index - 1):
+                lower_sibling = old_parent.child(old_index+1)
+                old_parent.removeChild(lower_sibling)
+                item.addChild(lower_sibling)
+
+                if lower_sibling not in items:
+                    was_expanded = True
+
+            old_parent.removeChild(item)
+            new_parent.insertChild(new_index, item)
+
+            self.expandItem(new_parent)
+            if was_expanded:
+                self.expandItem(item)
+
+    def _move_indent_right(self, items):
+        self._sort_items_by_index(items)
+
+        failed_parent = None
+        for item in items:
+            # indent right == become child of upper sibling
+            old_parent = item.parent() or self.invisibleRootItem()
+            old_idx = old_parent.indexOfChild(item)
+            was_expanded = item.isExpanded()
+
+            if old_idx <= 0:
+                # no upper sibling exists; cannot become child
+                failed_parent = old_parent
+                continue
+            elif failed_parent and old_parent is failed_parent:
+                # this prevents siblings at the same level from
+                # nesting into each other forming a "staircase"
+                continue
+            else:
+                failed_parent = None
+
+            new_parent = old_parent.child(old_idx-1)
+            old_parent.removeChild(item)
+            new_parent.addChild(item)
+
+            self.expandItem(new_parent)
+            if was_expanded:
+                self.expandItem(item)
+
+    def _move_indent(self, items, indent):
+        if not items or indent == 0:
+            return
+
+        # indent offsets are absolute (as opposed to relative to parent)
+        # child indented with parent automatically, no need for manual
+        items_ = self._get_root_items(items)
+        if len(items_) <= 0 or indent == 0:
+            return
+
+        focus_item = self.currentItem()
+
+        self.push_history()
+        if indent < 0:
+            self._move_indent_left(items_)
+        elif indent > 0:
+            self._move_indent_right(items_)
+
+        # restore previous focused item
+        if focus_item is None and items_:
+            focus_item = items_[0]
+
+        if focus_item:
+            self.setCurrentItem(
+                focus_item,
+                0,
+                QItemSelectionModel.SelectionFlag.ClearAndSelect
+            )
+
+        for item in items:
+            item.setSelected(True)
 
     def move_left(self):
-        if not self.check_multi_selection():
+        selected_items = self.selectedItems()
+        if len(selected_items) <= 0:
             return
-        self.push_history()
-        item = self.currentItem()
-        if item is not None:
-            parent = item.parent()
-            if parent is not None:
-                is_expanded = item.isExpanded() or item.childCount() == 0
-                gp = parent.parent() or self.invisibleRootItem()
-                idx = gp.indexOfChild(parent)
-                for gc in [parent.child(i) for i in range(parent.indexOfChild(item)+1, parent.childCount())]:
-                    parent.removeChild(gc)
-                    item.addChild(gc)
-                parent.removeChild(item)
-                gp.insertChild(idx+1, item)
-                if is_expanded:
-                    self.expandItem(item)
-                self.highlight_item(item)
+
+        self._move_indent(selected_items, -1)
 
     def move_right(self):
-        if not self.check_multi_selection():
+        selected_items = self.selectedItems()
+        if len(selected_items) <= 0:
             return
-        self.push_history()
-        item = self.currentItem()
-        if item is not None:
-            parent = item.parent() or self.invisibleRootItem()
-            idx = parent.indexOfChild(item)
-            if idx > 0:
-                is_expanded = item.isExpanded()
-                np = parent.child(idx-1)
-                parent.removeChild(item)
-                np.addChild(item)
-                if is_expanded:
-                    self.expandItem(item)
-                self.highlight_item(item)
+
+        self._move_indent(selected_items, 1)
 
     def move_down(self):
-        if not self.check_multi_selection():
+        selected_items = self.selectedItems()
+        if len(selected_items) <= 0:
             return
+
         self.push_history()
-        item = self.currentItem()
-        if item is None:
-            if self.root.childCount() == 0:
-                return
-            item = self.root.child(0)
-            self.highlight_item(item)
-            return
-        parent = item.parent() or self.root
-        idx = parent.indexOfChild(item)
-        if idx == parent.childCount() - 1:
-            # At end of parent, need to become sibling of parent
-            if parent is self.root:
-                return
-            gp = parent.parent() or self.root
-            parent.removeChild(item)
-            gp.insertChild(gp.indexOfChild(parent)+1, item)
-        else:
-            sibling = parent.child(idx+1)
-            parent.removeChild(item)
-            sibling.insertChild(0, item)
-        self.highlight_item(item)
+
+        items_ = self._get_root_items(selected_items)
+        self._sort_items_by_index(items_)
+
+        focus_item = self.currentItem()
+
+        for item in reversed(items_):
+            old_parent = item.parent() or self.invisibleRootItem()
+            old_index = old_parent.indexOfChild(item)
+            was_expanded = item.isExpanded() or item.childCount() == 0
+
+            new_parent = None
+            if old_index + 1 < old_parent.childCount():
+                # there is still space in parent; move down in same parent
+                old_parent.removeChild(item)
+                old_parent.insertChild(old_index + 1, item)
+            elif old_parent is not self.invisibleRootItem():
+                # move down past bottom of parent, become child of grandparent
+                new_parent = old_parent.parent() or self.invisibleRootItem()
+                old_parent.removeChild(item)
+                new_index = new_parent.indexOfChild(old_parent) + 1
+                new_parent.insertChild(new_index, item)
+                self.expandItem(new_parent)
+
+            self.expandItem(new_parent or old_parent)
+            if was_expanded:
+                self.expandItem(item)
+
+        if focus_item:
+            self.setCurrentItem(
+                focus_item,
+                0,
+                QItemSelectionModel.SelectionFlag.ClearAndSelect
+            )
+
+        for item in selected_items:
+            item.setSelected(True)
 
     def move_up(self):
-        if not self.check_multi_selection():
+        selected_items = self.selectedItems()
+        if len(selected_items) <= 0:
             return
+
         self.push_history()
-        item = self.currentItem()
-        if item is None:
-            if self.root.childCount() == 0:
-                return
-            item = self.root.child(self.root.childCount()-1)
-            self.highlight_item(item)
-            return
-        parent = item.parent() or self.root
-        idx = parent.indexOfChild(item)
-        if idx == 0:
-            # At end of parent, need to become sibling of parent
-            if parent is self.root:
-                return
-            gp = parent.parent() or self.root
-            parent.removeChild(item)
-            gp.insertChild(gp.indexOfChild(parent), item)
-        else:
-            sibling = parent.child(idx-1)
-            parent.removeChild(item)
-            sibling.addChild(item)
-        self.highlight_item(item)
+
+        items_ = self._get_root_items(selected_items)
+        self._sort_items_by_index(items_)
+
+        focus_item = self.currentItem()
+
+        for item in items_:
+            old_parent = item.parent() or self.invisibleRootItem()
+            old_index = old_parent.indexOfChild(item)
+            was_expanded = item.isExpanded() or item.childCount() == 0
+
+            new_parent = None
+            if old_index - 1 >= 0:
+                # there is still space in parent; move up within parent
+                old_parent.removeChild(item)
+                old_parent.insertChild(old_index - 1, item)
+            elif old_parent is not self.invisibleRootItem():
+                # move up past top of parent, become upper sibling of parent
+                new_parent = old_parent.parent() or self.invisibleRootItem()
+                old_parent.removeChild(item)
+                new_index = new_parent.indexOfChild(old_parent)
+                new_parent.insertChild(new_index, item)
+                self.expandItem(new_parent)
+
+            self.expandItem(new_parent or old_parent)
+            if was_expanded:
+                self.expandItem(item)
+
+        if focus_item:
+            self.setCurrentItem(
+                focus_item,
+                0,
+                QItemSelectionModel.SelectionFlag.ClearAndSelect
+            )
+
+        for item in selected_items:
+            item.setSelected(True)
 
     def del_items(self):
         self.push_history()
@@ -631,7 +796,7 @@ class TreeWidget(QTreeWidget):  # {{{
     def bulk_rename(self):
         from calibre.gui2.tweak_book.file_list import get_bulk_rename_settings
         sort_map = {id(item):i for i, item in enumerate(self.iter_items())}
-        items = sorted(self.selectedItems(), key=lambda x:sort_map.get(id(x), -1))
+        items = sorted(self.selectedItems(), key=lambda x: sort_map.get(id(x), -1))
         settings = get_bulk_rename_settings(self, len(items), prefix=_('Chapter '), msg=_(
             'All selected items will be renamed to the form prefix-number'), sanitize=lambda x:x, leading_zeros=False)
         fmt, num = settings['prefix'], settings['start']
@@ -641,16 +806,16 @@ class TreeWidget(QTreeWidget):  # {{{
                 item.setData(0, Qt.ItemDataRole.DisplayRole, fmt % (num + i))
 
     def keyPressEvent(self, ev):
-        if ev.key() == Qt.Key.Key_Left and ev.modifiers() & Qt.Modifier.CTRL:
+        if ev.key() == Qt.Key.Key_Left and ev.modifiers() & Qt.KeyboardModifier.ControlModifier:
             self.move_left()
             ev.accept()
-        elif ev.key() == Qt.Key.Key_Right and ev.modifiers() & Qt.Modifier.CTRL:
+        elif ev.key() == Qt.Key.Key_Right and ev.modifiers() & Qt.KeyboardModifier.ControlModifier:
             self.move_right()
             ev.accept()
-        elif ev.key() == Qt.Key.Key_Up and (ev.modifiers() & Qt.Modifier.CTRL or ev.modifiers() & Qt.Modifier.ALT):
+        elif ev.key() == Qt.Key.Key_Up and (ev.modifiers() & Qt.KeyboardModifier.ControlModifier or ev.modifiers() & Qt.KeyboardModifier.AltModifier):
             self.move_up()
             ev.accept()
-        elif ev.key() == Qt.Key.Key_Down and (ev.modifiers() & Qt.Modifier.CTRL or ev.modifiers() & Qt.Modifier.ALT):
+        elif ev.key() == Qt.Key.Key_Down and (ev.modifiers() & Qt.KeyboardModifier.ControlModifier or ev.modifiers() & Qt.KeyboardModifier.AltModifier):
             self.move_down()
             ev.accept()
         elif ev.key() in (Qt.Key.Key_Delete, Qt.Key.Key_Backspace):
@@ -663,26 +828,26 @@ class TreeWidget(QTreeWidget):  # {{{
         item = self.currentItem()
 
         def key(k):
-            sc = str(QKeySequence(k | Qt.Modifier.CTRL).toString(QKeySequence.SequenceFormat.NativeText))
-            return ' [%s]'%sc
+            sc = str(QKeySequence(k | Qt.KeyboardModifier.ControlModifier).toString(QKeySequence.SequenceFormat.NativeText))
+            return f' [{sc}]'
 
         if item is not None:
             m = QMenu(self)
-            m.addAction(QIcon(I('edit_input.png')), _('Change the location this entry points to'), self.edit_item)
-            m.addAction(QIcon(I('modified.png')), _('Bulk rename all selected items'), self.bulk_rename)
-            m.addAction(QIcon(I('trash.png')), _('Remove all selected items'), self.del_items)
+            m.addAction(QIcon.ic('edit_input.png'), _('Change the location this entry points to'), self.edit_item)
+            m.addAction(QIcon.ic('modified.png'), _('Bulk rename all selected items'), self.bulk_rename)
+            m.addAction(QIcon.ic('trash.png'), _('Remove all selected items'), self.del_items)
             m.addSeparator()
             ci = str(item.data(0, Qt.ItemDataRole.DisplayRole) or '')
             p = item.parent() or self.invisibleRootItem()
             idx = p.indexOfChild(item)
             if idx > 0:
-                m.addAction(QIcon(I('arrow-up.png')), (_('Move "%s" up')%ci)+key(Qt.Key.Key_Up), self.move_up)
+                m.addAction(QIcon.ic('arrow-up.png'), (_('Move "%s" up')%ci)+key(Qt.Key.Key_Up), self.move_up)
             if idx + 1 < p.childCount():
-                m.addAction(QIcon(I('arrow-down.png')), (_('Move "%s" down')%ci)+key(Qt.Key.Key_Down), self.move_down)
+                m.addAction(QIcon.ic('arrow-down.png'), (_('Move "%s" down')%ci)+key(Qt.Key.Key_Down), self.move_down)
             if item.parent() is not None:
-                m.addAction(QIcon(I('back.png')), (_('Unindent "%s"')%ci)+key(Qt.Key.Key_Left), self.move_left)
+                m.addAction(QIcon.ic('back.png'), (_('Unindent "%s"')%ci)+key(Qt.Key.Key_Left), self.move_left)
             if idx > 0:
-                m.addAction(QIcon(I('forward.png')), (_('Indent "%s"')%ci)+key(Qt.Key.Key_Right), self.move_right)
+                m.addAction(QIcon.ic('forward.png'), (_('Indent "%s"')%ci)+key(Qt.Key.Key_Right), self.move_right)
 
             m.addSeparator()
             case_menu = QMenu(_('Change case'), m)
@@ -693,7 +858,7 @@ class TreeWidget(QTreeWidget):  # {{{
             case_menu.addAction(_('Capitalize'), self.capitalize)
             m.addMenu(case_menu)
 
-            m.exec_(QCursor.pos())
+            m.exec(QCursor.pos())
 # }}}
 
 
@@ -711,35 +876,35 @@ class TOCView(QWidget):  # {{{
         self.tocw.edit_item.connect(self.edit_item)
         l.addWidget(t, 0, 0, 7, 3)
         self.up_button = b = QToolButton(self)
-        b.setIcon(QIcon(I('arrow-up.png')))
+        b.setIcon(QIcon.ic('arrow-up.png'))
         b.setIconSize(QSize(ICON_SIZE, ICON_SIZE))
         l.addWidget(b, 0, 3)
         b.setToolTip(_('Move current entry up [Ctrl+Up]'))
         b.clicked.connect(self.move_up)
 
         self.left_button = b = QToolButton(self)
-        b.setIcon(QIcon(I('back.png')))
+        b.setIcon(QIcon.ic('back.png'))
         b.setIconSize(QSize(ICON_SIZE, ICON_SIZE))
         l.addWidget(b, 2, 3)
         b.setToolTip(_('Unindent the current entry [Ctrl+Left]'))
         b.clicked.connect(self.tocw.move_left)
 
         self.del_button = b = QToolButton(self)
-        b.setIcon(QIcon(I('trash.png')))
+        b.setIcon(QIcon.ic('trash.png'))
         b.setIconSize(QSize(ICON_SIZE, ICON_SIZE))
         l.addWidget(b, 3, 3)
         b.setToolTip(_('Remove all selected entries'))
         b.clicked.connect(self.del_items)
 
         self.right_button = b = QToolButton(self)
-        b.setIcon(QIcon(I('forward.png')))
+        b.setIcon(QIcon.ic('forward.png'))
         b.setIconSize(QSize(ICON_SIZE, ICON_SIZE))
         l.addWidget(b, 4, 3)
         b.setToolTip(_('Indent the current entry [Ctrl+Right]'))
         b.clicked.connect(self.tocw.move_right)
 
         self.down_button = b = QToolButton(self)
-        b.setIcon(QIcon(I('arrow-down.png')))
+        b.setIcon(QIcon.ic('arrow-down.png'))
         b.setIconSize(QSize(ICON_SIZE, ICON_SIZE))
         l.addWidget(b, 6, 3)
         b.setToolTip(_('Move current entry down [Ctrl+Down]'))
@@ -870,9 +1035,9 @@ class TOCView(QWidget):  # {{{
         self.toc = get_toc(self.ebook)
         self.toc_lang, self.toc_uid = self.toc.lang, self.toc.uid
         self.toc_title = self.toc.toc_title
-        self.blank = QIcon(I('blank.png'))
-        self.ok = QIcon(I('ok.png'))
-        self.err = QIcon(I('dot_red.png'))
+        self.blank = QIcon.ic('blank.png')
+        self.ok = QIcon.ic('ok.png')
+        self.err = QIcon.ic('dot_red.png')
         self.icon_map = {None:self.blank, True:self.ok, False:self.err}
 
         def process_item(toc_node, parent):
@@ -946,8 +1111,8 @@ class TOCView(QWidget):  # {{{
         process_node(self.root, toc, nodes)
         self.highlight_item(nodes[0])
 
-    def create_from_xpath(self, xpaths, remove_duplicates=True):
-        toc = from_xpaths(self.ebook, xpaths)
+    def create_from_xpath(self, xpaths, remove_duplicates=True, prefer_title=False):
+        toc = from_xpaths(self.ebook, xpaths, prefer_title=prefer_title)
         if len(toc) == 0:
             return error_dialog(self, _('No items found'),
                 _('No items were found that could be added to the Table of Contents.'), show=True)
@@ -972,7 +1137,6 @@ class TOCView(QWidget):  # {{{
     def undo(self):
         self.tocw.pop_history()
 
-
 # }}}
 
 
@@ -995,7 +1159,7 @@ class TOCEditor(QDialog):  # {{{
         t = title or os.path.basename(pathtobook)
         self.book_title = t
         self.setWindowTitle(_('Edit the ToC in %s')%t)
-        self.setWindowIcon(QIcon(I('highlight_only_on.png')))
+        self.setWindowIcon(QIcon.ic('highlight_only_on.png'))
 
         l = self.l = QVBoxLayout()
         self.setLayout(l)
@@ -1004,8 +1168,7 @@ class TOCEditor(QDialog):  # {{{
         l.addWidget(s)
         self.loading_widget = lw = QWidget(self)
         s.addWidget(lw)
-        ll = self.ll = QVBoxLayout()
-        lw.setLayout(ll)
+        ll = self.ll = QVBoxLayout(lw)
         self.pi = pi = ProgressIndicator()
         pi.setDisplaySize(QSize(200, 200))
         pi.startAnimation()
@@ -1028,20 +1191,19 @@ class TOCEditor(QDialog):  # {{{
         bb.rejected.connect(self.reject)
         self.undo_button = b = bb.addButton(_('&Undo'), QDialogButtonBox.ButtonRole.ActionRole)
         b.setToolTip(_('Undo the last action, if any'))
-        b.setIcon(QIcon(I('edit-undo.png')))
+        b.setIcon(QIcon.ic('edit-undo.png'))
         b.clicked.connect(self.toc_view.undo)
 
         self.explode_done.connect(self.read_toc, type=Qt.ConnectionType.QueuedConnection)
         self.writing_done.connect(self.really_accept, type=Qt.ConnectionType.QueuedConnection)
 
-        r = QApplication.desktop().availableGeometry(self)
-        self.resize(r.width() - 100, r.height() - 100)
-        geom = self.prefs.get('toc_editor_window_geom', None)
-        if geom is not None:
-            QApplication.instance().safe_restore_geometry(self, bytes(geom))
+        self.restore_geometry(self.prefs, 'toc_editor_window_geom')
         self.stacks.currentChanged.connect(self.update_history_buttons)
         self.update_history_buttons()
 
+    def sizeHint(self):
+        return QSize(900, 600)
+
     def update_history_buttons(self):
         self.undo_button.setVisible(self.stacks.currentIndex() == 1)
         self.undo_button.setEnabled(bool(self.toc_view.tocw.history))
@@ -1049,6 +1211,15 @@ class TOCEditor(QDialog):  # {{{
     def add_new_item(self, item, where):
         self.item_edit(item, where)
         self.stacks.setCurrentIndex(2)
+        if ismacos:
+            QTimer.singleShot(0, self.workaround_macos_mouse_with_webview_bug)
+
+    def workaround_macos_mouse_with_webview_bug(self):
+        # macOS is weird: https://bugs.launchpad.net/calibre/+bug/2004639
+        # needed as of Qt 6.4.2
+        d = info_dialog(self, _('Loading...'), _('Loading table of contents view, please wait...'), show_copy_button=False)
+        QTimer.singleShot(0, d.reject)
+        d.exec()
 
     def accept(self):
         if monotonic() - self.last_accept_at < 1:
@@ -1068,7 +1239,7 @@ class TOCEditor(QDialog):  # {{{
             self.bb.setEnabled(False)
 
     def really_accept(self, tb):
-        self.prefs['toc_editor_window_geom'] = bytearray(self.saveGeometry())
+        self.save_geometry(self.prefs, 'toc_editor_window_geom')
         if tb:
             error_dialog(self, _('Failed to write book'),
                 _('Could not write %s. Click "Show details" for'
@@ -1089,7 +1260,7 @@ class TOCEditor(QDialog):  # {{{
             self.stacks.setCurrentIndex(1)
         else:
             self.working = False
-            self.prefs['toc_editor_window_geom'] = bytearray(self.saveGeometry())
+            self.save_geometry(self.prefs, 'toc_editor_window_geom')
             self.write_result(1)
             super().reject()
 
@@ -1111,7 +1282,7 @@ class TOCEditor(QDialog):  # {{{
         tb = None
         try:
             self.ebook = get_container(self.pathtobook, log=self.log)
-        except:
+        except Exception:
             import traceback
             tb = traceback.format_exc()
         if self.working:
@@ -1138,7 +1309,7 @@ class TOCEditor(QDialog):  # {{{
             commit_toc(self.ebook, toc, lang=self.toc_view.toc_lang,
                     uid=self.toc_view.toc_uid)
             self.ebook.commit()
-        except:
+        except Exception:
             import traceback
             tb = traceback.format_exc()
         self.writing_done.emit(tb)
@@ -1146,7 +1317,25 @@ class TOCEditor(QDialog):  # {{{
 # }}}
 
 
-def main(path=None, title=None):
+def develop():
+    from calibre.gui2 import Application
+    app = Application([])
+    from calibre.utils.webengine import setup_default_profile, setup_fake_protocol
+    setup_fake_protocol()
+    setup_default_profile()
+    d = TOCEditor(sys.argv[-1])
+    d.start()
+    d.open()
+    app.exec()
+    del app
+
+
+def main(shm_name=None):
+    import json
+    import struct
+
+    from calibre.utils.shm import SharedMemory
+
     # Ensure we can continue to function if GUI is closed
     os.environ.pop('CALIBRE_WORKER_TEMP_DIR', None)
     reset_base_dir()
@@ -1155,21 +1344,33 @@ def main(path=None, title=None):
         # prevents them from being grouped with viewer/editor process when
         # launched from within calibre, as both use calibre-parallel.exe
         set_app_uid(TOC_DIALOG_APP_UID)
+    with SharedMemory(name=shm_name) as shm:
+        pos = struct.calcsize('>II')
+        state, ok = struct.unpack('>II', shm.read(pos))
+        data = json.loads(shm.read_data_with_size())
+        title = data['title']
+        path = data['path']
+        s = struct.pack('>I', 1)
+        shm.seek(0), shm.write(s), shm.flush()
+
+        override = 'calibre-gui' if islinux else None
+        app = Application([], override_program_name=override)
+        from calibre.utils.webengine import setup_default_profile, setup_fake_protocol
+        setup_fake_protocol()
+        setup_default_profile()
+        d = TOCEditor(path, title=title, write_result_to=path + '.result')
+        d.start()
+        # Using d.exec() causes showing the webview to hide the dialog
+        d.open()
+        app.exec()
+        ok = 1 if d.result() == QDialog.DialogCode.Accepted else 0
+        s = struct.pack('>II', 2, ok)
+        shm.seek(0), shm.write(s), shm.flush()
 
-    with open(path + '.started', 'w'):
-        pass
-    override = 'calibre-gui' if islinux else None
-    app = Application([], override_program_name=override)
-    d = TOCEditor(path, title=title, write_result_to=path + '.result')
-    d.start()
-    ret = 1
-    if d.exec_() == QDialog.DialogCode.Accepted:
-        ret = 0
     del d
     del app
-    raise SystemExit(ret)
+    raise SystemExit(0 if ok else 1)
 
 
 if __name__ == '__main__':
-    main(path=sys.argv[-1], title='test')
-    os.remove(sys.argv[-1] + '.lock')
+    develop()
