@@ -7,11 +7,36 @@ __copyright__ = '2013, Kovid Goyal <kovid at kovidgoyal.net>'
 import os
 import sys
 from functools import partial
+
 from qt.core import (
-    QAbstractListModel, QApplication, QCheckBox, QFormLayout, QGridLayout, QClipboard,
-    QHBoxLayout, QIcon, QInputDialog, QLabel, QLineEdit, QListView, QMenu, QPainter,
-    QPixmap, QRect, QSize, QSizePolicy, QSortFilterProxyModel, QStyledItemDelegate,
-    Qt, QToolButton, QTreeWidget, QTreeWidgetItem, QVBoxLayout, pyqtSignal, QDialog, QDialogButtonBox
+    QAbstractListModel,
+    QApplication,
+    QCheckBox,
+    QClipboard,
+    QDialog,
+    QDialogButtonBox,
+    QFormLayout,
+    QGridLayout,
+    QHBoxLayout,
+    QIcon,
+    QInputDialog,
+    QLabel,
+    QLineEdit,
+    QListView,
+    QMenu,
+    QPainter,
+    QPixmap,
+    QRect,
+    QSize,
+    QSizePolicy,
+    QSortFilterProxyModel,
+    QStyledItemDelegate,
+    Qt,
+    QToolButton,
+    QTreeWidget,
+    QTreeWidgetItem,
+    QVBoxLayout,
+    pyqtSignal,
 )
 
 from calibre import fit_image
@@ -23,6 +48,7 @@ from calibre.gui2.tweak_book import current_container, tprefs
 from calibre.gui2.tweak_book.file_list import name_is_ok
 from calibre.gui2.tweak_book.widgets import Dialog
 from calibre.ptempfile import PersistentTemporaryFile
+from calibre.startup import connect_lambda
 from calibre.utils.icu import numeric_sort_key
 from calibre.utils.localization import canonicalize_lang, get_lang
 from calibre_extensions.progress_indicator import set_no_activate_on_click
@@ -69,8 +95,8 @@ class ChooseName(Dialog):  # {{{
         super().accept()
 # }}}
 
-# Images {{{
 
+# Images {{{
 
 class ImageDelegate(QStyledItemDelegate):
 
@@ -115,7 +141,7 @@ class ImageDelegate(QStyledItemDelegate):
             cover = self.cover_cache[name] = QPixmap()
             try:
                 raw = current_container().raw_data(name, decode=False)
-            except:
+            except Exception:
                 pass
             else:
                 try:
@@ -347,6 +373,7 @@ class InsertImage(Dialog):
     def filter_changed(self, *args):
         f = str(self.filter.text())
         self.fm.setFilterFixedString(f)
+
 # }}}
 
 
@@ -490,7 +517,7 @@ class NewBook(Dialog):  # {{{
 
 
 if __name__ == '__main__':
-    app = QApplication([])  # noqa
+    app = QApplication([])  # noqa: F841
     from calibre.gui2.tweak_book import set_current_container
     from calibre.gui2.tweak_book.boss import get_container
     set_current_container(get_container(sys.argv[-1]))
