@@ -75,9 +75,11 @@ author_name_suffixes = ('Jr', 'Sr', 'Inc', 'Ph.D', 'Phd',
                         'MD', 'M.D', 'I', 'II', 'III', 'IV',
                         'Junior', 'Senior')
 author_name_prefixes = ('Mr', 'Mrs', 'Ms', 'Dr', 'Prof')
-author_name_copywords = ('Agency', 'Corporation', 'Company', 'Co.', 'Council',
-                         'Committee', 'Inc.', 'Institute', 'National',
-                         'Society', 'Club', 'Team')
+author_name_copywords = (
+    'Agency', 'Corporation', 'Company', 'Co.', 'Council',
+    'Committee', 'Inc.', 'Institute', 'National', 'Society', 'Club', 'Team',
+    'Software', 'Games', 'Entertainment', 'Media', 'Studios',
+)
 author_use_surname_prefixes = False
 author_surname_prefixes = ('da', 'de', 'di', 'la', 'le', 'van', 'von')
 
@@ -89,20 +91,24 @@ author_surname_prefixes = ('da', 'de', 'di', 'la', 'le', 'van', 'von')
 # Default: r'(?i),?\s+(and|with)\s+'
 authors_split_regex = r'(?i),?\s+(and|with)\s+'
 
-#: Use author sort in Tag browser
-# Set which author field to display in the Tag browser (the list of authors,
-# series, publishers etc on the left hand side). The choices are author and
-# author_sort. This tweak affects only what is displayed under the authors
-# category in the Tag browser and Content server. Please note that if you set this
-# to author_sort, it is very possible to see duplicate names in the list because
-# although it is guaranteed that author names are unique, there is no such
-# guarantee for author_sort values. Showing duplicates won't break anything, but
-# it could lead to some confusion. When using 'author_sort', the tooltip will
-# show the author's name.
+#: Use author_sort and/or series_sort for names in Tag browser
+# Set which author or series field is used to display as the item name in the
+# Tag browser (the list of authors, series, publishers etc on the left hand
+# side). The choices for author are 'author' and 'author_sort'. The choices for
+# series are 'series' and 'series_sort'. This tweak affects only what is
+# displayed under the category in the Tag browser and Content server. Please
+# note that if you set this to …_sort, it is possible to see duplicate names in
+# the list because although it is guaranteed that author and series names are
+# unique, there is no such guarantee for their sort values. Showing duplicates
+# won't break anything but it could lead to some confusion. The tooltip for an
+# item will show the item's name no matter how you set this tweak.
 # Examples:
 #   categories_use_field_for_author_name = 'author'
 #   categories_use_field_for_author_name = 'author_sort'
+#   categories_use_field_for_series_name = 'series'
+#   categories_use_field_for_series_name = 'series_sort'
 categories_use_field_for_author_name = 'author'
+categories_use_field_for_series_name = 'series'
 
 #: Control partitioning of Tag browser
 # When partitioning the Tag browser, the format of the subcategory label is
@@ -141,22 +147,24 @@ sort_columns_at_startup = None
 #  A string controlling how the publication date is displayed in the GUI
 #  d     the day as number without a leading zero (1 to 31)
 #  dd    the day as number with a leading zero (01 to 31)
-#  ddd   the abbreviated localized day name (e.g. 'Mon' to 'Sun').
-#  dddd  the long localized day name (e.g. 'Monday' to 'Sunday').
+#  ddd   the abbreviated localized day name (e.g. 'Mon' to 'Sun')
+#  dddd  the long localized day name (e.g. 'Monday' to 'Sunday')
 #  M     the month as number without a leading zero (1-12)
 #  MM    the month as number with a leading zero (01-12)
-#  MMM   the abbreviated localized month name (e.g. 'Jan' to 'Dec').
-#  MMMM  the long localized month name (e.g. 'January' to 'December').
+#  MMM   the abbreviated localized month name (e.g. 'Jan' to 'Dec')
+#  MMMM  the long localized month name (e.g. 'January' to 'December')
 #  yy    the year as two digit number (00-99)
 #  yyyy  the year as four digit number
-#  h     the hours without a leading 0 (0 to 11 or 0 to 23, depending on am/pm) '
-#  hh    the hours with a leading 0 (00 to 11 or 00 to 23, depending on am/pm) '
-#  m     the minutes without a leading 0 (0 to 59) '
-#  mm    the minutes with a leading 0 (00 to 59) '
-#  s     the seconds without a leading 0 (0 to 59) '
-#  ss    the seconds with a leading 0 (00 to 59) '
-#  ap    use a 12-hour clock instead of a 24-hour clock, with "ap" replaced by the localized string for am or pm
-#  AP    use a 12-hour clock instead of a 24-hour clock, with "AP" replaced by the localized string for AM or PM
+#  h     the hours without a leading 0 (0 to 11 or 0 to 23, depending on am/pm)
+#  hh    the hours with a leading 0 (00 to 11 or 00 to 23, depending on am/pm)
+#  m     the minutes without a leading 0 (0 to 59)
+#  mm    the minutes with a leading 0 (00 to 59)
+#  s     the seconds without a leading 0 (0 to 59)
+#  ss    the seconds with a leading 0 (00 to 59)
+#  ap    use a 12-hour clock instead of a 24-hour clock, with "ap" replaced by the lowercase localized string for am or pm
+#  AP    use a 12-hour clock instead of a 24-hour clock, with "AP" replaced by the uppercase localized string for AM or PM
+#  aP    use a 12-hour clock instead of a 24-hour clock, with "aP" replaced by the localized string for am or pm
+#  Ap    use a 12-hour clock instead of a 24-hour clock, with "Ap" replaced by the localized string for AM or PM
 #  iso   the date with time and timezone. Must be the only format present
 #  For example, given the date of 9 Jan 2010, the following formats show
 #  MMM yyyy ==> Jan 2010    yyyy ==> 2010       dd MMM yyyy ==> 09 Jan 2010
@@ -214,49 +222,49 @@ save_template_title_series_sorting = 'library_order'
 # (present only for legacy reasons).
 per_language_title_sort_articles = {
         # English
-        'eng'  : (r'A\s+', r'The\s+', r'An\s+'),
+        'eng': (r'A\s+', r'The\s+', r'An\s+'),
         # Esperanto
         'epo': (r'La\s+', r"L'", 'L´'),
         # Spanish
-        'spa'  : (r'El\s+', r'La\s+', r'Lo\s+', r'Los\s+', r'Las\s+', r'Un\s+',
-                  r'Una\s+', r'Unos\s+', r'Unas\s+'),
+        'spa': (r'El\s+', r'La\s+', r'Lo\s+', r'Los\s+', r'Las\s+', r'Un\s+',
+                r'Una\s+', r'Unos\s+', r'Unas\s+'),
         # French
-        'fra'  : (r'Le\s+', r'La\s+', r"L'", u'L´', u'L’', r'Les\s+', r'Un\s+', r'Une\s+',
-                  r'Des\s+', r'De\s+La\s+', r'De\s+', r"D'", r'D´', r'D’'),
+        'fra': (r'Le\s+', r'La\s+', r"L'", r'L´', r'L’', r'Les\s+', r'Un\s+', r'Une\s+',
+                r'Des\s+', r'De\s+La\s+', r'De\s+', r"D'", r'D´', r'D’'),
         # Polish
         'pol': (),
         # Italian
-        'ita': ('Lo\\s+', 'Il\\s+', "L'", 'L´', 'La\\s+', 'Gli\\s+',
-                'I\\s+', 'Le\\s+', 'Uno\\s+', 'Un\\s+', 'Una\\s+', "Un'",
-                'Un´', 'Dei\\s+', 'Degli\\s+', 'Delle\\s+', 'Del\\s+',
-                'Della\\s+', 'Dello\\s+', "Dell'", 'Dell´'),
+        'ita': (r'Lo\s+', r'Il\s+', r"L'", r'L´', r'La\s+', r'Gli\s+',
+                r'I\s+', r'Le\s+', r'Uno\s+', r'Un\s+', r'Una\s+', "rUn'",
+                r'Un´', r'Dei\s+', r'Degli\s+', r'Delle\s+', r'Del\s+',
+                r'Della\s+', r'Dello\s+', r"Dell'", r'Dell´'),
         # Portuguese
-        'por'  : (r'A\s+', r'O\s+', r'Os\s+', r'As\s+', r'Um\s+', r'Uns\s+',
-                  r'Uma\s+', r'Umas\s+', ),
+        'por': (r'A\s+', r'O\s+', r'Os\s+', r'As\s+', r'Um\s+', r'Uns\s+',
+                r'Uma\s+', r'Umas\s+'),
         # Romanian
-        'ron'  : (r'Un\s+', r'O\s+', r'Nişte\s+', ),
+        'ron': (r'Un\s+', r'O\s+', r'Nişte\s+'),
         # German
-        'deu'  : (r'Der\s+', r'Die\s+', r'Das\s+', r'Den\s+', r'Ein\s+',
-                  r'Eine\s+', r'Einen\s+', r'Dem\s+', r'Des\s+', r'Einem\s+',
-                  r'Eines\s+'),
+        'deu': (r'Der\s+', r'Die\s+', r'Das\s+', r'Den\s+', r'Ein\s+',
+                r'Eine\s+', r'Einen\s+', r'Dem\s+', r'Des\s+', r'Einem\s+',
+                r'Eines\s+'),
         # Dutch
-        'nld'  : (r'De\s+', r'Het\s+', r'Een\s+', r"'n\s+", r"'s\s+", r'Ene\s+',
-                  r'Ener\s+', r'Enes\s+', r'Den\s+', r'Der\s+', r'Des\s+',
-                  r"'t\s+"),
+        'nld': (r'De\s+', r'Het\s+', r'Een\s+', r"'n\s+", r"'s\s+", r'Ene\s+',
+                r'Ener\s+', r'Enes\s+', r'Den\s+', r'Der\s+', r'Des\s+',
+                r"'t\s+"),
         # Swedish
-        'swe'  : (r'En\s+', r'Ett\s+', r'Det\s+', r'Den\s+', r'De\s+', ),
+        'swe': (r'En\s+', r'Ett\s+', r'Det\s+', r'Den\s+', r'De\s+'),
         # Turkish
-        'tur'  : (r'Bir\s+', ),
+        'tur': (r'Bir\s+',),
         # Afrikaans
-        'afr'  : (r"'n\s+", r'Die\s+', ),
+        'afr': (r"'n\s+", r'Die\s+'),
         # Greek
-        'ell'  : (r'O\s+', r'I\s+', r'To\s+', r'Ta\s+', r'Tus\s+', r'Tis\s+',
-                  r"'Enas\s+", r"'Mia\s+", r"'Ena\s+", r"'Enan\s+", ),
+        'ell': (r'O\s+', r'I\s+', r'To\s+', r'Ta\s+', r'Tus\s+', r'Tis\s+',
+                r"'Enas\s+", r"'Mia\s+", r"'Ena\s+", r"'Enan\s+"),
         # Hungarian
-        'hun'  : (r'A\s+', r'Az\s+', r'Egy\s+',),
+        'hun': (r'A\s+', r'Az\s+', r'Egy\s+'),
 }
 default_language_for_title_sort = None
-title_sort_articles=r'^(A|The|An)\s+'
+title_sort_articles = r'^(A|The|An)\s+'
 
 #: Specify a folder calibre should connect to at startup
 # Specify a folder that calibre should connect to at startup using
@@ -329,8 +337,8 @@ auto_connect_to_folder = ''
 # The resulting two tweaks are:
 #    sony_collection_renaming_rules={'series':'Series', 'tags':'Tag'}
 #    sony_collection_name_template='{category:||: }{value}'
-sony_collection_renaming_rules={}
-sony_collection_name_template='{value}{category:| (|)}'
+sony_collection_renaming_rules = {}
+sony_collection_name_template = '{value}{category:| (|)}'
 
 #: Specify how SONY collections are sorted
 # Specify how SONY collections are sorted. This tweak is only applicable if
@@ -377,9 +385,10 @@ cover_trim_fuzz_value = 10
 
 #: Control behavior of the book list
 # You can control the behavior of double clicks and pressing Enter on the books
-# list. Choices: open_viewer, do_nothing, show_book_details, edit_cell,
-# edit_metadata. Selecting anything other than open_viewer or show_book_details
-# has the side effect of disabling editing a field using a single click.
+# list. Choices: open_viewer, do_nothing, show_book_details,
+# show_locked_book_details, edit_cell, edit_metadata. Selecting anything other
+# than open_viewer, show_book_details, or show_locked_book_details has the side
+# effect of disabling editing a field using a single click.
 # Default: open_viewer.
 # Example: doubleclick_on_library_view = 'do_nothing'
 # You can also control whether the book list scrolls per item or
@@ -399,7 +408,7 @@ vertical_scrolling_per_row = False
 # Default: locale_for_sorting = '' -- use the language calibre displays in
 # Example: locale_for_sorting = 'fr' -- sort using French rules.
 # Example: locale_for_sorting = 'nb' -- sort using Norwegian rules.
-locale_for_sorting =  ''
+locale_for_sorting = ''
 
 #: The number of seconds to wait before sending emails
 # The number of seconds to wait before sending emails when using a
@@ -424,7 +433,7 @@ maximum_cover_size = (1650, 2200)
 # control where it is sent. Valid values are "main", "carda", "cardb". Note
 # that if there isn't enough free space available on the location you choose,
 # the files will be sent to the location with the most free space.
-send_news_to_device_location = "main"
+send_news_to_device_location = 'main'
 
 #: Unified toolbar on macOS
 # If you enable this option and restart calibre, the toolbar will be 'unified'
@@ -522,12 +531,6 @@ content_server_thumbnail_compression_quality = 75
 #    cover_drop_exclude = {'tiff', 'webp'}
 cover_drop_exclude = ()
 
-#: Show the Saved searches box in the Search bar
-# In newer versions of calibre, only a single button that allows you to add a
-# new Saved search is shown in the Search bar. If you would like to have the
-# old Saved searches box with its two buttons back, set this tweak to True.
-show_saved_search_box = False
-
 #: Exclude fields when copy/pasting metadata
 # You can ask calibre to not paste some metadata fields when using the
 # Edit metadata->Copy metadata/Paste metadata actions. For example,
@@ -567,3 +570,34 @@ value_for_undefined_numbers_when_sorting = 0
 # using these functions in composites can be very slow.
 # Default: False
 allow_template_database_functions_in_composites = False
+
+
+#: Change the programs that are run when opening files/URLs
+# By default, calibre passes URLs to the operating system to open using
+# whatever default programs are configured there. Here you can override
+# that by specifying the program to use, per URL type. For local files,
+# the type is "file" and for web links it is "http*". For example:
+# openers_by_scheme = { "http*": "firefox %u" } will make calibre run Firefox
+# for https://whatever URLs. %u is replaced by the URL to be opened. The scheme
+# takes a glob pattern allowing a single entry to match multiple URL types.
+openers_by_scheme = {}
+
+#: Set the first day of the week for calendar popups
+# It must be one of the values Default, Sunday, Monday, Tuesday, Wednesday,
+# Thursday, Friday, or Saturday, all in English, spelled exactly as shown.
+calendar_start_day_of_week = 'Default'
+
+#: East Asian language to use for transliteration
+# Setting this tweak will make calibre use the specified language as the "base"
+# language when transliterating East Asian languages to English. This might be
+# useful if you run calibre in English but want text transliterated to
+# Japanese instead of Chinese. The valid values are:
+#   'ja' for Japanese
+#   'kr' for Korean
+#   'vn' for Vietnamese
+#   'zh' for Chinese
+# Any other value will use the language set in calibre preferences as the base
+# language. A base language other than those in the above list causes transliteration
+# with a base language of Chinese.
+# Example: east_asian_base_language = 'ja'
+east_asian_base_language = ''
